<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * Post management functions used by the GetSimple News Manager Plugin.
 */


/*******************************************************
 * @function nm_admin_main
 * @action back-end main panel (post overview)
 */
function nm_admin_panel() {
  global $PRETTYURLS, $NMPRETTYURLS;
  include(NMTEMPLATEPATH . 'panel_header.php');
  $posts = nm_get_posts(TRUE);
  if (!empty($posts)) {
    echo '<table class="highlight">';
    include(NMTEMPLATEPATH . 'panel_table_header.php');
    foreach ($posts as $slug=>$file) {
      $url = nm_get_url('post') . $slug;
      $data = getXML($file);
      $title = cl($data->title);
      $date = shtDate($data->date);
      include(NMTEMPLATEPATH . 'panel_table_row.php');
    }
    echo '</table>';
  }
  echo '<p><b>' . count($posts) . '</b> ' . i18n_r('news_manager/POSTS') . '</p>';
}


/*******************************************************
 * @function nm_delete_post
 * @param $slug - post slug
 * @action deletes the requested post
 */
function nm_delete_post($slug) {
  $file = NMDATAPATH . "$slug.xml";
  if (file_exists($file)) {
    if (unlink($file))
      nm_display_message(i18n_r('news_manager/SUCCESS_DELETE_POST'));
    else
      nm_display_message(i18n_r('news_manager/ERROR_DELETE_POST'), TRUE);
  }
}


/*******************************************************
 * @function nm_edit_post
 * @param $slug - post slug
 * @action edit or create posts
 */
function nm_edit_post($slug) {
  $file = NMDATAPATH . "$slug.xml";
  # get post data, if it exists
  $data = @getXML($file);
  $title = @stripslashes($data->title);
  $date = !empty($data) ? date('m/d/Y', strtotime($data->date)) : '';
  $time = !empty($data) ? date('H:i', strtotime($data->date)) : '';
  $tags = @str_replace(',', ', ', ($data->tags));
  $private = @$data->private != '' ? 'checked' : '';
  $content = @stripslashes($data->content);
  # show edit post form
  include(NMTEMPLATEPATH . 'edit_post.php');
  if (file_exists($file)) {
    $mtime = date(i18n_r('DATE_AND_TIME_FORMAT'), filemtime($file));
    echo '<small>' . i18n_r('news_manager/LAST_SAVED') . ": $mtime</small>";
  }
  include(NMTEMPLATEPATH . 'ckeditor.php');
}


/*******************************************************
 * @function nm_save_post
 * @action write $_POST data to xml file
 */
function nm_save_post() {
  if ($_POST['post-title'] == '') {
    nm_display_message(i18n_r('news_manager/ERROR_EMPTY_TITLE'), TRUE);
  } else {
    # set initial slug and filename
    if ($_POST['post-slug'] != '')
      $slug = nm_create_slug($_POST['post-slug']);
    else
      $slug = nm_create_slug($_POST['post-title']);
    $file = NMDATAPATH . "$slug.xml";
    # are we creating a new file?
    if (!isset($_POST['current-slug']) || $_POST['current-slug'] != $slug) {
      # delete old post file
      if (isset($_POST['current-slug']))
        unlink(NMDATAPATH . $_POST['current-slug'] . '.xml');
      # do not overwrite existing files
      if (file_exists($file)) {
        $count = 1;
        $file = NMDATAPATH . "$slug-$count.xml";
        while (file_exists($file))
          $file = NMDATAPATH . "$slug-" . ++$count . '.xml';
        $slug .= "-$count";
      }
    }
    # collect $_POST data
    $title = safe_slash_html($_POST['post-title']);
    $timestamp = strtotime($_POST['post-date'] . ' ' . $_POST['post-time']);
    $date = $timestamp ? date('r', $timestamp) : date('r');
    $tags = str_replace(array(' ', ',,'), array('', ','), safe_slash_html($_POST['post-tags']));
    $private = isset($_POST['post-private']) ? 'Y' : '';
    $content = safe_slash_html($_POST['post-content']);
    # create xml object
    $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><item></item>');
    $obj = $xml->addChild('title');
    $obj->addCData($title);
    $obj = $xml->addChild('date');
    $obj->addCData($date);
    $obj = $xml->addChild('private');
    $obj->addCData($private);
    $obj = $xml->addChild('tags');
    $obj->addCData($tags);
    $obj = $xml->addChild('content');
    $obj->addCData($content);
    # write data to file
    if (!@XMLsave($xml, $file))
      nm_display_message(i18n_r('news_manager/ERROR_SAVE_POST'), TRUE);
    else
      nm_display_message(i18n_r('news_manager/SUCCESS_SAVE_POST'));
  }
}


?>
