<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * General functions used by the GetSimple News Manager Plugin.
 */


/*******************************************************
 * @function is_pos_int
 * @return TRUE when $value is a positive integer, FALSE otherwise
 */
function is_pos_int($value) {
  return is_numeric($value) && $value > 0;
}


/*******************************************************
 * @function nm_get_url
 * @return url of front-end newspage, with optional query
 */
function nm_get_url($query=FALSE) {
  global $SITEURL, $PRETTYURLS, $NMPAGEURL, $NMPRETTYURLS;
  $data = getXML(GSDATAPAGESPATH . $NMPAGEURL . '.xml');
  $url = find_url($NMPAGEURL, $data->parent);
  if ($query) {
    if ($PRETTYURLS == 1 && $NMPRETTYURLS == 'Y')
      $url .= $query . '/';
    elseif ($NMPAGEURL == 'index')
      $url = $SITEURL . "index.php?$query=";
    else
      $url = $SITEURL . "index.php?id=$NMPAGEURL&$query=";
  }
  return $url;
}


/*******************************************************
 * @function nm_get_languages
 * @return array with language files in NMLANGPATH
 */
function nm_get_languages() {
  $languages = array();
  $files = getFiles(NMLANGPATH);
  foreach ($files as $file) {
    if (isFile($file, NMLANGPATH, 'php')) {
      $lang = basename($file, '.php');
      $languages[$lang] = NMLANGPATH . $file;
    }
  }
  ksort($languages);
  return $languages;
}


/*******************************************************
 * @function nm_get_posts
 * @param $private when TRUE include private posts
 * @return array with posts in the NMDATAPATH folder, sorted by date
 */
function nm_get_posts($private=FALSE) {
  $posts = $dates = array();
  $files = getFiles(NMDATAPATH);
  foreach ($files as $file) {
    if (isFile($file, NMDATAPATH, 'xml')) {
      $data = getXML(NMDATAPATH . $file);
      if (!$private && $data->private == 'Y')
          continue;
      $slug = basename($file, '.xml');
      $timestamp = strtotime($data->date);
      $dates[$timestamp] = $slug;
    }
  }
  krsort($dates);
  foreach($dates as $date=>$slug)
    $posts[$slug] = NMDATAPATH . "$slug.xml";
  return $posts;
}



/*******************************************************
 * @function nm_get_archives
 * @return array with monthly archives
 */
function nm_get_archives() {
  $archives = array();
  $posts = nm_get_posts();
  foreach ($posts as $slug=>$file) {
    $data = getXML($file);
    $date = strtotime($data->date);
    $title = nm_get_date($date, '%B %Y');
    $archive = date('Ym', $date);
    if (!array_key_exists($archive, $archives))
      $archives[$archive] = $title;
  }
  krsort($archives);
  return $archives;
}


/*******************************************************
 * @function nm_get_tags
 * @return array with unique tags (keys) and counts (values)
 */
function nm_get_tags() {
  $tags = array();
  $posts = nm_get_posts();
  foreach ($posts as $slug=>$file) {
    $data = getXML($file);
    if (!empty($data->tags))
      $tags = array_merge($tags, explode(',', $data->tags));
  }
  sort($tags);
  return array_count_values($tags);
}


/*******************************************************
 * @function nm_get_date
 * @param $timestamp UNIX timestamp
 * @return date formatted according to $NNLANG
 */
function nm_get_date($timestamp, $format) {
  global $NMLANG;
  $locale = setlocale(LC_TIME, NULL);
  setlocale(LC_TIME, $NMLANG);
  $date = strftime($format, $timestamp);
  setlocale(LC_TIME, $locale);
  return $date;
}


/*******************************************************
 * @function nm_create_slug
 * @param $str string
 * @return a url friendly version of $str
 */
function nm_create_slug($str) {
  $str = to7bit($str, 'UTF-8');
  $str = clean_url($str);
  return $str;
}


/*******************************************************
 * @function nm_create_excerpt
 * @param $content the post content
 * @return a truncated version of the post content
 */
function nm_create_excerpt($content) {
  global $NMEXCERPTLENGTH;
  $len = intval($NMEXCERPTLENGTH);
  $content = strip_tags($content);
  if (strlen($content) > $len) {
    if (function_exists('mb_substr'))
      $content = trim(mb_substr($content, 0, $len, 'UTF-8')) . ' [...]';
    else
      $content = trim(substr($content, 0, $len)) . ' [...]';
  }
  return "<p>$content</p>";
}


/*******************************************************
 * @function nm_i18n_merge
 * @action update the $i18n language array
 */
function nm_i18n_merge() {
  global $NMLANG;
  if (isset($NMLANG) && $NMLANG != '') {
    include(NMLANGPATH . "$NMLANG.php");
    $nm_i18n = $i18n;
    global $i18n;
    foreach ($nm_i18n as $code=>$text)
      $i18n['news_manager/' . $code] = $text;
  }
}


/*******************************************************
 * @function nm_display_message
 * @param $msg a string containing the message
 * @param $error if TRUE, show as $msg as error, else as update
 * @action display status messages on back-end pages
 */
function nm_display_message($msg, $error=FALSE) {
  if (isset($msg)) {
    ?>
    <script type="text/javascript">
      $(function() {
        $('div.bodycontent').before('<div class="<?php echo $error ? 'error' : 'updated'; ?>" style="display:block;">'+
          <?php echo json_encode($msg); ?>+'</div>');
        $(".updated, .error").fadeOut(500).fadeIn(500);
      });
    </script>
    <?php
  }
}


?>
