<?php if (!defined('IN_GS')) {die('you cannot load this page directly.');}

/**
 * Back-end configuration functions used by the GetSimple News Manager Plugin.
 */


/*******************************************************
 * @function nm_env_check
 * @action check plugin environment (config & folder)
 */
function nm_env_check() {
  $config = !file_exists(NMCONFIG) ? nm_write_config_file() : TRUE;
  $folder = !file_exists(NMDATAPATH) ? nm_create_data_folder() : TRUE;
  if (!$config || !$folder)
    echo '<p>' . i18n_r('news_manager/ERROR_ENV') . '</p>';
  return ($config && $folder);
}


/*******************************************************
 * @function nm_write_config_file
 * @action write plugin settings to config file
 */
function nm_write_config_file() {
  global $NMPAGEURL, $NMPRETTYURLS, $NMLANG, $NMSHOWEXCERPT, $NMEXCERPTLENGTH, $NMPOSTSPERPAGE, $NMRECENTPOSTS;
  $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><item></item>');
  $obj = $xml->addChild('page_url');
  $obj->addCData($NMPAGEURL);
  $obj = $xml->addChild('pretty_urls');
  $obj->addCData($NMPRETTYURLS);
  $obj = $xml->addChild('language');
  $obj->addCData($NMLANG);
  $obj = $xml->addChild('show_excerpt');
  $obj->addCData($NMSHOWEXCERPT);
  $obj = $xml->addChild('excerpt_length');
  $obj->addCData($NMEXCERPTLENGTH);
  $obj = $xml->addChild('posts_per_page');
  $obj->addCData($NMPOSTSPERPAGE);
  $obj = $xml->addChild('recent_posts');
  $obj->addCData($NMRECENTPOSTS);
  return @XMLsave($xml, NMCONFIG);
}


/*******************************************************
 * @function nm_create_data_folder
 * @action create the folder /data/posts and make it writable
 */
function nm_create_data_folder() {
  if (mkdir(NMDATAPATH, 0777)) {
    $fh = fopen(NMDATAPATH . '.htaccess', 'w');
    fwrite($fh, 'Deny from all');
    fclose($fh);
    return TRUE;
  } else {
    return FALSE;
  }
}


/*******************************************************
 * @function nm_edit_settings
 * @action edit plugin configuration settings
 */
function nm_edit_settings() {
  global $PRETTYURLS, $NMPAGEURL, $NMPRETTYURLS, $NMLANG, $NMSHOWEXCERPT, $NMEXCERPTLENGTH, $NMPOSTSPERPAGE, $NMRECENTPOSTS;
  include(NMTEMPLATEPATH . 'edit_settings.php');
}


/*******************************************************
 * @function nm_save_settings
 * @action parse POST data and save to config file
 */
function nm_save_settings() {
  global $NMPAGEURL, $NMPRETTYURLS, $NMLANG, $NMSHOWEXCERPT, $NMEXCERPTLENGTH, $NMPOSTSPERPAGE, $NMRECENTPOSTS;
  $backup = array('page_url' => $NMPAGEURL, 'pretty_urls' => $NMPRETTYURLS);
  # parse $_POST
  $NMPAGEURL = $_POST['page-url'];
  $NMPRETTYURLS = isset($_POST['pretty-urls']) ? 'Y' : '';
  $NMLANG = $_POST['language'];
  $NMSHOWEXCERPT = $_POST['show-excerpt'] ? 'Y' : '';
  if (is_pos_int($_POST['excerpt-length']))
    $NMEXCERPTLENGTH = $_POST['excerpt-length'];
  if (is_pos_int($_POST['posts-per-page']))
    $NMPOSTSPERPAGE = $_POST['posts-per-page'];
  if (is_pos_int($_POST['recent-posts']))
    $NMRECENTPOSTS = $_POST['recent-posts'];
  # write settings to file
  if (!nm_write_config_file())
    nm_display_message(i18n_r('news_manager/ERROR_SAVE_CONFIG'), TRUE);
  else
    nm_display_message(i18n_r('news_manager/SUCCESS_SAVE_CONFIG'));
  # should we update .htaccess?
  if ($NMPRETTYURLS == 'Y') {
    if ($backup['pretty_urls'] != 'Y' || $backup['page_url'] != $NMPAGEURL)
      nm_display_message(i18n_r('news_manager/UPDATE_HTACCESS'), TRUE);
  }
}


/*******************************************************
 * @function nm_generate_htaccess
 * @action generate a .htaccess sample config based on current settings
 */
function nm_generate_htaccess() {
  global $NMPAGEURL;
  $path = tsl(suggest_site_path(TRUE));
  $prefix = '';
  $page =  '';
  # format prefix and page directions
  if ($NMPAGEURL != 'index') {
    $data = getXML(GSDATAPAGESPATH . $NMPAGEURL . '.xml');
    $parent = $data->parent;
    $prefix = $parent != '' ? "$parent/$NMPAGEURL/" : "$NMPAGEURL/";
    $page = "id=$NMPAGEURL&";
  }
  # generate .htaccess contents
  $htaccess = file_get_contents(GSPLUGINPATH . 'news_manager/temp.htaccess');
  $htaccess = str_replace('**PATH**', $path, $htaccess);
  $htaccess = str_replace('**PREFIX**', $prefix, $htaccess);
  $htaccess = str_replace('**PAGE**', $page, $htaccess);
  $htaccess = safe_slash_html($htaccess);
  # show .htaccess
  include(NMTEMPLATEPATH . 'htaccess.php');
}


?>
